==> jscommunicator-1.0.21.tgz: package/lib/genericPromotionalMail.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var MailGenericPromotional = function (_base$Base) {
  _inherits(MailGenericPromotional, _base$Base);

  function MailGenericPromotional(host, config, appName) {
    _classCallCheck(this, MailGenericPromotional);

    return _possibleConstructorReturn(this, (MailGenericPromotional.__proto__ || Object.getPrototypeOf(MailGenericPromotional)).call(this, host, config, appName));
  }

  _createClass(MailGenericPromotional, [{
    key: 'sendMail',
    value: function sendMail(fromName, fromMail, subject, body, emailType, files, to, hash, referenceId, referenceType) {
      var toName = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : "";
      var cc = arguments.length > 11 && arguments[11] !== undefined ? arguments[11] : "";
      var bcc = arguments.length > 12 && arguments[12] !== undefined ? arguments[12] : "";
      var plaintext = arguments.length > 13 && arguments[13] !== undefined ? arguments[13] : "";
      var replyTo = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : null;
      var expiryTime = arguments.length > 15 && arguments[15] !== undefined ? arguments[15] : null;
      var createdBy = arguments.length > 16 && arguments[16] !== undefined ? arguments[16] : null;

      this.validateMailType(emailType.toUpperCase());
      var job = new types.GenericPromotionalMail();
      job.from_name = fromName;
      job.from_address = fromMail;
      job.to_name = toName;
      job.to_address = to;
      job.expiry_time = expiryTime;
      job.subject = subject;
      job.body = body;
      job.plaintext = plaintext;
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.app_name = this.appName;
      job.created_by = createdBy;
      job.email_type = emailType.toUpperCase();
      job.reply_to = replyTo;
      job.hash = hash;
      job.mail_type = 'generic_promotional';

      if (referenceId !== parseInt(referenceId, 10)) {
        throw "referenceId should be integer";
      }
      if (typeof cc == 'string' && cc.length > 0) {
        job.cc = [cc];
      } else {
        job.cc = cc;
      }
      if (typeof bcc == 'string' && bcc.length > 0) {
        job.bcc = [bcc];
      } else {
        job.bcc = bcc;
      }

      var attachments = [];
      if (files) {
        for (var i = 0; i < files.length; i++) {
          var att = new types.Attachment();
          att.name = files[i];
          att.location = files[files[i]];
          attachments.push(att);
        }
      }
      job.attachments = attachments;
      this.send(job, this.queueNames.sendGenericPromotionalMailQueue, 0);
    }
  }, {
    key: 'getMailCountByType',
    value: function getMailCountByType(mailType, startDate, endDate, deliveryStatus, callback) {
      var data = {};
      data.start_date = startDate;
      data.end_date = endDate;
      data.mail_type = mailType;
      data.delivery_status = deliveryStatus;
      this.get('/genericpromotionalmail/get_mail_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateMailType',
    value: function validateMailType(type) {
      var allowedTypes = [];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return MailGenericPromotional;
}(base.Base);

module.exports = {
  MailGenericPromotional: MailGenericPromotional
};

==> jscommunicator-1.0.27.tgz: package/lib/genericPromotionalMail.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var base = require('./base');
var types = require('./types');

var MailGenericPromotional = function (_base$Base) {
  _inherits(MailGenericPromotional, _base$Base);

  function MailGenericPromotional(request, config, appName) {
    _classCallCheck(this, MailGenericPromotional);

    return _possibleConstructorReturn(this, (MailGenericPromotional.__proto__ || Object.getPrototypeOf(MailGenericPromotional)).call(this, request, config, appName));
  }

  _createClass(MailGenericPromotional, [{
    key: 'sendMail',
    value: function sendMail(fromName, fromMail, subject, body, emailType, files, to, hash, referenceId, referenceType) {
      var toName = arguments.length > 10 && arguments[10] !== undefined ? arguments[10] : "";
      var cc = arguments.length > 11 && arguments[11] !== undefined ? arguments[11] : "";
      var bcc = arguments.length > 12 && arguments[12] !== undefined ? arguments[12] : "";
      var plaintext = arguments.length > 13 && arguments[13] !== undefined ? arguments[13] : "";
      var replyTo = arguments.length > 14 && arguments[14] !== undefined ? arguments[14] : null;
      var expiryTime = arguments.length > 15 && arguments[15] !== undefined ? arguments[15] : null;
      var createdBy = arguments.length > 16 && arguments[16] !== undefined ? arguments[16] : null;
      var campaignId = arguments.length > 17 && arguments[17] !== undefined ? arguments[17] : null;

      this.validateMailType(emailType.toUpperCase());
      var job = new types.GenericPromotionalMail();
      job.from_name = fromName;
      job.from_address = fromMail;
      job.to_name = toName;
      job.to_address = to;
      job.expiry_time = expiryTime;
      job.subject = subject;
      job.body = body;
      job.plaintext = plaintext;
      job.reference_id = referenceId;
      job.reference_type = referenceType;
      job.app_name = this.appName;
      job.created_by = createdBy;
      job.email_type = emailType.toUpperCase();
      job.reply_to = replyTo;
      job.hash = hash;
      job.campaign_id = campaignId;
      job.mail_type = 'generic_promotional';

      if (referenceId !== parseInt(referenceId, 10)) {
        throw "referenceId should be integer";
      }
      if (typeof cc == 'string' && cc.length > 0) {
        job.cc = [cc];
      } else {
        job.cc = cc;
      }
      if (typeof bcc == 'string' && bcc.length > 0) {
        job.bcc = [bcc];
      } else {
        job.bcc = bcc;
      }

      var attachments = [];
      if (files) {
        for (var i = 0; i < files.length; i++) {
          var att = new types.Attachment();
          att.name = files[i];
          att.location = files[files[i]];
          attachments.push(att);
        }
      }
      job.attachments = attachments;
      this.send(job, this.queueNames.sendGenericPromotionalMailQueue, 0);
    }
  }, {
    key: 'getMailCountByType',
    value: function getMailCountByType(mailType, startDate, endDate, deliveryStatus, callback) {
      var data = {};
      data.start_date = startDate;
      data.end_date = endDate;
      data.mail_type = mailType;
      data.delivery_status = deliveryStatus;
      this.get('/genericpromotionalmail/get_mail_count_for_type', data, function (err, response) {
        if (err) {
          callback(err);
        } else {
          callback(null, response);
        }
      });
    }
  }, {
    key: 'validateMailType',
    value: function validateMailType(type) {
      var allowedTypes = [];

      if (allowedTypes.indexOf(type) < 0) {
        throw "Invalid mail type";
      }
    }
  }]);

  return MailGenericPromotional;
}(base.Base);

module.exports = {
  MailGenericPromotional: MailGenericPromotional
};
